@@ -9,6 +9,7 @@ from .typeahead_obj_widget import TypeAheadObjWidget
 from .typeahead_widget import TypeAheadWidget
 from .objects_pics_widget import ObjectsPicsWidget
 from .file_widget import FileWidget
+from .pics_subfolder_widget import PicsSubfolderWidget
 
 __widgets__: dict[str, Type['Widget']] = {
     'text_widget': TextWidget,
@@ -19,7 +20,8 @@ __widgets__: dict[str, Type['Widget']] = {
     'type_ahead_object_widget': TypeAheadObjWidget,
     'objects_pics_widget': ObjectsPicsWidget,
     'type_ahead_widget': TypeAheadWidget,
-    'file_widget': FileWidget
+    'file_widget': FileWidget,
+    'pics_subfolder_widget': PicsSubfolderWidget,
 }
 
 
